function [] = getpc_scans(trueTrack,env_param,scan_param,part_filt_parameters)
% Function that generates scan observations based on true tracks and environment description
% Input
%     trueTrack  - True tracks of the object (2xnum_scans)
%     env_param  - Description of the environment
%     scan_param - parameters for scan generation
% 
% Output
%     scan_out   - A vector of scan images in polar form

%% Parameters
num_scans = length(trueTrack);
range_res = (scan_param.range_max-scan_param.range_min)/scan_param.range_count;
angle_res = (scan_param.angle_max-scan_param.angle_min)/scan_param.angle_count;

%variables to hold plotting data
range_vec = scan_param.range_min:range_res:(scan_param.range_max-range_res);
azimuth_vec = (scan_param.angle_min:angle_res:(scan_param.angle_max-angle_res)) + pi;


%% Motion Model
%motion model info
motion_x = trueTrack(1,:);
motion_y = trueTrack(2,:);
% TODO: Orientation
motion_orientation = 0; 

%% Observation load and change 

% obstacle info - get from env_param
sim_env = env_param.sim_env;
[trajectory_y,trajectory_x] = find(sim_env);
% Scale to real lengths and move to origin
trajectory_x = trajectory_x-floor(env_param.num_pix/2);
trajectory_y = -(trajectory_y-floor(env_param.num_pix/2));
trajectory_x = trajectory_x.*env_param.res_xy + env_param.origin(1);
trajectory_y = trajectory_y.*env_param.res_xy + env_param.origin(2);
% Random downsample to proportion
old_count = length(trajectory_x);
select_vec = rand(old_count,1);
select_truth = select_vec < env_param.env_ds;
trajectory_x = trajectory_x(select_truth);
trajectory_y = trajectory_y(select_truth);

object_count = size(trajectory_x,1);

% Subtract motion model
rel_trajectory_x = trajectory_x-ones(object_count,1)*motion_x;
rel_trajectory_y = trajectory_y-ones(object_count,1)*motion_y;

% Add Motion Model Noise

%% Convert Scans to Polar Images
rel_trajectory_x_scale = (rel_trajectory_x*scan_param.scale_dist);
rel_trajectory_y_scale = (rel_trajectory_y*scan_param.scale_dist);

[angle_traj, range_traj] = cart2pol(rel_trajectory_x_scale,rel_trajectory_y_scale);

% Adding Noise
range_traj_n = range_traj + normrnd(scan_param.muMeasurementNoiseRange,scan_param.sigmaMeasurementNoiseRange,size(range_traj));
angle_traj_n = angle_traj + normrnd(scan_param.muMeasurementNoiseAngle,scan_param.sigmaMeasurementNoiseAngle,size(angle_traj));

% Clip
truth_range = (range_traj_n>scan_param.range_min) & (range_traj_n<scan_param.range_max);
truth_angle = (angle_traj_n>scan_param.angle_min) & (angle_traj_n<scan_param.angle_max);
truth_pol   = truth_range & truth_angle;

fftData = zeros(scan_param.angle_count,scan_param.range_count,num_scans);

for scan_ind = 1:num_scans
    r_ind = range_traj_n(truth_pol(:,scan_ind),scan_ind);
    a_ind = angle_traj_n(truth_pol(:,scan_ind),scan_ind);
    
    % Scale and Discretize
    range_traj_fov = floor((r_ind-scan_param.range_min)/range_res)+1;
    angle_traj_fov = floor((a_ind-scan_param.angle_min)/angle_res)+1;
    
    ind_set_1 = sub2ind([scan_param.angle_count,scan_param.range_count,num_scans],angle_traj_fov,range_traj_fov,...
                        scan_ind*ones(length(a_ind),1));
    fftData(ind_set_1) = scan_param.obst_ampl;
    
    % Generating Clutter
    clutter_mat = rand(scan_param.angle_count,scan_param.range_count);
    truth_one = clutter_mat < scan_param.clutter_prob;
    clutter_mat(truth_one) = scan_param.clutter_mag;
    clutter_mat(~truth_one) = 0;
    
    % Smoothing
    fftData(:,:,scan_ind) = fftData(:,:,scan_ind) + clutter_mat;
    fftData(:,:,scan_ind) = scan_param.smooth_mult*...
                        imgaussfilt(fftData(:,:,scan_ind), scan_param.sigma_gauss_smooth);
                    
    % Background noise
    add_noise = normrnd(scan_param.mu_bg,scan_param.sigma_bg,scan_param.angle_count,scan_param.range_count);
    fftData(:,:,scan_ind) = fftData(:,:,scan_ind) + add_noise;
    
end
fftData = abs(fftData);

if(scan_param.save_flag)
    
    ins.x = motion_x*scan_param.scale_dist;
    ins.y = motion_y*scan_param.scale_dist;

    radarData = {};
    for scan_ind = 1:num_scans

        % radar.azimuths, radar.fftData, radar.radarResolution,
        radar2.azimuths = azimuth_vec;
        radar2.radarResolution = range_res;
        radar2.fftData = fftData(:,:,scan_ind);
        radarData{scan_ind,1} = radar2;

    end



    save(scan_param.save_filename,'radarData','ins','scan_param','env_param','part_filt_parameters');



end

end