function [feat_det_param] = get_feat_detector_params(feat_detector_flag)

feat_det_param.feat_detector_flag = feat_detector_flag;
feat_det_param.plot_flag = 0;

%% Point Cloud Converter Parameters
param_img2pcloud.dn_thresh = 2;
param_img2pcloud.dn_nn     = 10;
param_img2pcloud.ds_type   = 'random';
param_img2pcloud.ds_arg    = 0.2;

feat_det_param.param_img2pcloud = param_img2pcloud;

%% Main Detector parameter switch
switch (feat_detector_flag)
    case 0
        % Fast OS CFAR Filter Initialization
        feat_det_param.num_train = 200;
        feat_det_param.num_guard = 45;
        feat_det_param.order = 310;
        feat_det_param.thresh = db2pow(6);
        feat_det_param.input_mask_clean = 1;
        
        % Cartesian visualisation size (used for both height and width)
        feat_det_param.cart_resolution = .25/2; 
        feat_det_param.cart_pixel_size = 501*2-1; % pixels
        feat_det_param.interpolate_crossover = true;
        
    case 1
        % Fast CA CFAR
        feat_det_param.num_train = 400;
        feat_det_param.num_guard = 45;
        feat_det_param.thresh = 6.6;
        feat_det_param.input_mask_clean = 1;
        
        % Cartesian visualisation size (used for both height and width)
        feat_det_param.cart_resolution = .03; 
        feat_det_param.cart_pixel_size = 501*2-1; % pixels
        feat_det_param.interpolate_crossover = true;

    case 2
        % Fast CA CFAR SIM
        feat_det_param.num_train = 400;
        feat_det_param.num_guard = 45;
        feat_det_param.thresh = 10;
        feat_det_param.input_mask_clean = 0;
        
        % Cartesian visualisation size (used for both height and width)
        feat_det_param.cart_resolution = .03; 
        feat_det_param.cart_pixel_size = 501*2-1; % pixels
        feat_det_param.interpolate_crossover = true;
        
    otherwise
        error('Feat Detector not supported')
end

%% Mask Cleaner Parameters (TODO)


end