function [scan_match_param] = get_scan_match_alg_params(scan_match_flag)

scan_match_param.scan_match_flag = scan_match_flag;

switch scan_match_flag
    case 0
        % ICP
        scan_match_param.inlier_ratio = 0.9;
        scan_match_param.max_iter     = 100;
        scan_match_param.metric       = 'pointToPoint';
        scan_match_param.extrapolate  = true;
        scan_match_param.tolerance     = [0.01 0.5]; 
    case 1
        % NDT
        scan_match_param.grid_step     = 5;
        scan_match_param.outlier_ratio = 0.1;
        scan_match_param.max_iter      = 100;
        scan_match_param.tolerance     = [0.01 0.5];
    case 2
        % CPD
        scan_match_param.outlier_ratio    = 0.1;
        scan_match_param.Transform        = 'Rigid';
        scan_match_param.max_iter         = 100;
        scan_match_param.tolerance        = 1e-5;
        scan_match_param.InteractionSigma = 2; % Not used for Rigid Transformation
        scan_match_param.SmoothingWeight  = 3; % Not used for Rigid Transformation
    case 3
        % PDA Based (Slow)
        scan_match_param.knn = 8;
        scan_match_param.is2d_flag = 1;
        % Solver Options
        % Create using optimoptions(@lsqnonlin)
        % x = lsqcurvefit(fun,x0,xdata,ydata)
        scan_match_param.solver_options = optimoptions(@lsqnonlin);
        % pda_param.solver_options
        scan_match_param.solver_options.Algorithm = 'levenberg-marquardt';
        scan_match_param.solver_options.Display = 'none'; % iter-detailed
        scan_match_param.solver_options.StepTolerance = 1e-2;
        % pda_param.solver_options.TypicalX = [];
        scan_match_param.solver_options
        
    otherwise
        error('Scan Match algorithm not supported!')
end


end