function [odo_xy,particles] = performEstimationParticlesPCCorr(radarData,part_filt_params,feat_det_param,scan_match_param)

% load system part_filt_params
numSteps = length(radarData)-1;
numParticles = part_filt_params.numParticles;
scanTime = part_filt_params.scanTime;
sigmaDrivingNoise = part_filt_params.sigmaDrivingNoise;

pcloud_match_var = part_filt_params.pcloud_match_var;

priorMean = part_filt_params.priorMean;
priorCovariance = part_filt_params.priorCovariance;
[A,W,~] = getModelMatrices(scanTime);

% initialize particles and estimated track
particles = zeros(4,numParticles,numSteps+1);
particles(:,:,1) = repmat(priorMean,[1,numParticles]) + sqrtm(priorCovariance) * randn(4,numParticles);
odo_xy = zeros(4,numSteps);

[~,ptcloud_old] = feat_detect_helper(radarData{1},feat_det_param);
% recursive update
for step = 1:numSteps
%     tic
step
% if(step == 35)
%    1; 
% end
    % prediction
    pred_increment = W*sigmaDrivingNoise*randn(2,numParticles);
    particles(:,:,step+1) = A*particles(:,:,step) + pred_increment;
        
    % prediction for observations
    radar = radarData{step+1};
    % Feature Detection and Cleaning
    [plot_vars,ptcloud_new] = feat_detect_helper(radar,feat_det_param);
    
    % Update Step
%     % Calculate Unnormalized weights
    weights = zeros(1,numParticles);
    for index = 1:numParticles
        part_pc_shiftedxy = ptcloud_old.Location(:,1:2) + pred_increment(1:2,index).';
        part_pc_shiftedxyz = [part_pc_shiftedxy,zeros(length(part_pc_shiftedxy),1)];
        
        [indices,dists] = knnsearch(part_pc_shiftedxyz,ptcloud_new.Location,'K',1);
        weights(index) = rms(dists);
    end
    mean(weights)
    % Weights Normalization
%     weights = weights-max(weights);
    weights = exp(-(weights.^2)/2*(pcloud_match_var));
    weights = weights./sum(weights);
    
    % Resampling
    particles(:,:,step+1) = particles(:,resampleSystematic(weights,numParticles),step+1);
    
    % Estimation
    odo_xy(:,step) = mean(particles(:,:,step+1),2);
    
%     toc
end

particles = particles(:,:,2:numSteps+1);

end