function [] = radar_odometry_plotter(plot_struct)
% 
%     plot_struct = struct('cart_pixel_size',cart_pixel_size,...
%                          'cart_resolution',cart_resolution,...
%                          'cart_img',cart_img,...
%                          'cart_col',cart_col,...
%                          'cart_row',cart_row,...
%                          'fft_col',fft_col,...
%                          'fft_row',fft_row,...
%                          'ptcloud_old',ptcloud_old,...
%                          'tformpcloud',tformpcloud,...
%                          'ptcloud_old_old',ptcloud_old_old,...
%                          );

persistent h;
persistent s;
persistent pc_handle;

if nargin<1
   h = [];
   s = [];
   pc_handle = [];
   return
end

if isempty(h)
       
        fig = figure(72327);
        fig.Name = "Odometry Visualisation";
        fig.NumberTitle = "off";

        % Cartesian Plot
        pixel_range = floor(plot_struct.cart_pixel_size / 2);
        tick_labels = (-pixel_range:pixel_range) * plot_struct.cart_resolution;
        tick_locs = [1, pixel_range+1, plot_struct.cart_pixel_size];
        sp2 = subplot(1, 2, 1, 'align');

        h{1} = imagesc(plot_struct.cart_img, [0, 0.5]);
        hold on
        s{1} = scatter(plot_struct.cart_col,plot_struct.cart_row,'r+','Parent', sp2);
        hold off
        
        xticks(tick_locs);
        yticks(tick_locs);
        axis image;
        ylabel('X (metres)', 'FontSize', 12);
        yticklabels(-tick_labels(yticks));
        xlabel('Y (metres)', 'FontSize', 12);
        xticklabels(tick_labels(xticks));
        title('Cartesian Radar Visualisation', 'FontSize', 14);
        set(sp2, 'XColor', [1 1 1], 'YColor', [1 1 1], 'ZColor', [1 1 1])
        % Pcloud plot
        lgd1 = legend({'CFAR Filtered'},'FontSize',15,'Location',...
            'southoutside');
        fig.Name = "Radar Odometry Example";
        fig.NumberTitle = "off";
        sp1 = subplot(1, 2, 2, 'align');
        pc_handle = pcshow(plot_struct.ptcloud_old);
        
        xlim([-floor(plot_struct.cart_pixel_size/2) floor(plot_struct.cart_pixel_size/2)])
        ylim([-floor(plot_struct.cart_pixel_size/2) floor(plot_struct.cart_pixel_size/2)])
        view(pc_handle,90,-90)
        
else
        h{1}.CData = plot_struct.cart_img;
        s{1}.XData = plot_struct.cart_col;
        s{1}.YData = plot_struct.cart_row;
        
        %
        colorvec = uint8(ones(plot_struct.ptcloud_old.Count,3)).*uint8([0 255 0]);
        plot_struct.ptcloud_old.Color = colorvec;
        pcshow(plot_struct.ptcloud_old,'Parent',pc_handle)
        hold(pc_handle,'on')
        %
        colorvec = uint8(ones(plot_struct.tformpcloud.Count,3)).*uint8([255 0 0]);
        plot_struct.tformpcloud.Color = colorvec;
        pcshow(plot_struct.tformpcloud,'Parent',pc_handle)
        %
        colorvec = uint8(ones(plot_struct.ptcloud_old_old.Count,3)).*uint8([0 0 255]);
        plot_struct.ptcloud_old_old.Color = colorvec;
        pcshow(plot_struct.ptcloud_old_old,'Parent',pc_handle)
        hold(pc_handle,'off')
        
        xlabel('X','FontSize',18,'Parent',pc_handle)
        ylabel('Y','FontSize',18,'Parent',pc_handle)
        view(pc_handle,90,-90)
        xlim(pc_handle,[-floor(plot_struct.cart_pixel_size/2) floor(plot_struct.cart_pixel_size/2)])
        ylim(pc_handle,[-floor(plot_struct.cart_pixel_size/2) floor(plot_struct.cart_pixel_size/2)])
        title("ICP",'Parent',pc_handle)
        lgd = legend({'Previous','Transformed','Current'},'FontSize',15);
        lgd.Location = 'southoutside';
        lgd.TextColor = [1 1 1];
end
    drawnow;

end



%% Recycle Bin

%     radar.fftData_filt = radar.fftData.*(detout.');
%     [fft_row,fft_col] = ind2sub(size(radar.fftData_filt),find(detout.'));
        
%         range_ticks = ((1:size(fft_data_vis, 2))-0.5) * ...
%             radar.radarResolution * downsample_rate;
        
        % Polar Plot
%         colormap gray;
%         sp1 = subplot(1, 2, 1, 'align');
%         h{1} = imagesc(fft_data_vis, [0, 0.5]);set(gca,'ydir','normal');
%         hold on
%         s{1} = scatter(fft_col,fft_row,'r+','Parent', sp1);
%         hold off
%         yticklabels(radar.azimuths(yticks));
%         ylabel('Azimuth (radians)', 'FontSize', 12);
%         xticklabels(range_ticks(xticks));
%         xlabel('Range (metres)', 'FontSize', 12);
%         title('Polar Radar Visualisation', 'FontSize', 14);