%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script to perform Radar Odometry
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Data Loading

data_load_flag = 0; % 0 for sim, 1 for real data 
switch (data_load_flag)
    case 0
        load('myDatasim2')
    case 1
        load('myData')
    otherwise
        error('Wrong data_load_flag !')
end

%% Parameters
% Partition Scans
numScans = size(radarData,1);
min_scan = 1;
max_scan = round(0.33*numScans);

% Feature Detectors
feat_detector_flag = 2; % 0 for OS CFAR, 1 for CA CFAR, 2 for CA CFAR Sim
feat_det_param = get_feat_detector_params(feat_detector_flag);
feat_det_param.plot_flag = 0;

% Scan Match Algorithms
scan_match_flag = 0; % 0 - ICP, 1 - NDT, 2 - CPD, 3 - Custom
scan_match_param = get_scan_match_alg_params(scan_match_flag); 

% If motion model known:
[part_filt_params] = get_part_filt_param(part_filt_parameters);

% Which one to use
odo_est_flag = 0; % 0 Blind estimator, 1 Particle Based using motion model

switch odo_est_flag
   
    case 0
        %% Blind Radar Odometry Implementation
        [frames_to_video,odo_xy,rmse_vec] = radarOdometry_blind(radarData(min_scan:max_scan),...
                                                                feat_det_param,scan_match_param);

        
    case 1
        %% Particle filter based estimation when motion model is known
        [odo_xy,particles] = performEstimationParticlesPCCorr(radarData(min_scan:max_scan),...
                                        part_filt_params,feat_det_param,scan_match_param);

        
    otherwise
        error('Not Implemented')
    
end


%% Plotting Results
int_range = min_scan:max_scan;
int_range_frac = [min_scan max_scan]/numScans;
int_ins_range = length(ins.x)*int_range_frac;
int_ins_range = round(int_ins_range(1)):round(int_ins_range(2));

pix_range_scale = feat_det_param.cart_resolution;
figure(1)
odoplot = plot(pix_range_scale*odo_xy(1,1),pix_range_scale*odo_xy(1,2));

for idx = min_scan:max(int_range)
plt_range = min_scan:idx;

switch (data_load_flag)
    case 0
        odoplot.XData = pix_range_scale*odo_xy(plt_range,1);
        odoplot.YData = pix_range_scale*odo_xy(plt_range,2);
    case 1
        odoplot.XData = -pix_range_scale*odo_xy(plt_range,2);
        odoplot.YData = -pix_range_scale*odo_xy(plt_range,1);
    otherwise
        error('Wrong data_load_flag !')
end
% pause(0.01);
end

hold on
plot(ins.x(int_ins_range)-ins.x(int_ins_range(1)),...
    ins.y(int_ins_range)-ins.y(int_ins_range(1)))
hold off
set(findall(gca, 'Type', 'Line'),'LineWidth',2);

legend({'Radar Only', 'INS'},'FontSize',14)
title({'Naive Radar Odometry'},'FontSize',14)
xlabel('X movement (m)','FontSize',14)
ylabel('Y movement (m)','FontSize',14)


